@@ -1,34 +1,34 @@
-( cd usr/bin ; rm -rf iptables-xml )
-( cd usr/bin ; ln -sf /usr/sbin/iptables-multi iptables-xml )
-( cd usr/sbin ; rm -rf ip6tables-save )
-( cd usr/sbin ; ln -sf ip6tables-multi ip6tables-save )
-( cd usr/sbin ; rm -rf ip6tables-restore )
-( cd usr/sbin ; ln -sf ip6tables-multi ip6tables-restore )
-( cd usr/sbin ; rm -rf iptables-save )
-( cd usr/sbin ; ln -sf iptables-multi iptables-save )
-( cd usr/sbin ; rm -rf iptables )
-( cd usr/sbin ; ln -sf iptables-multi iptables )
-( cd usr/sbin ; rm -rf iptables-restore )
-( cd usr/sbin ; ln -sf iptables-multi iptables-restore )
-( cd usr/sbin ; rm -rf ip6tables )
-( cd usr/sbin ; ln -sf ip6tables-multi ip6tables )
-( cd usr/lib ; rm -rf libiptc.so.0 )
-( cd usr/lib ; ln -sf libiptc.so.0.0.0 libiptc.so.0 )
 ( cd usr/lib ; rm -rf libipq.so )
 ( cd usr/lib ; ln -sf libipq.so.0.0.0 libipq.so )
+( cd usr/lib ; rm -rf libip6tc.so.0 )
+( cd usr/lib ; ln -sf libip6tc.so.0.1.0 libip6tc.so.0 )
+( cd usr/lib ; rm -rf libxtables.so.7 )
+( cd usr/lib ; ln -sf libxtables.so.7.0.0 libxtables.so.7 )
 ( cd usr/lib ; rm -rf libipq.so.0 )
 ( cd usr/lib ; ln -sf libipq.so.0.0.0 libipq.so.0 )
 ( cd usr/lib ; rm -rf libip6tc.so )
-( cd usr/lib ; ln -sf libip6tc.so.0.0.0 libip6tc.so )
-( cd usr/lib ; rm -rf libip4tc.so.0 )
-( cd usr/lib ; ln -sf libip4tc.so.0.0.0 libip4tc.so.0 )
+( cd usr/lib ; ln -sf libip6tc.so.0.1.0 libip6tc.so )
 ( cd usr/lib ; rm -rf libxtables.so )
-( cd usr/lib ; ln -sf libxtables.so.5.0.0 libxtables.so )
+( cd usr/lib ; ln -sf libxtables.so.7.0.0 libxtables.so )
 ( cd usr/lib ; rm -rf libiptc.so )
 ( cd usr/lib ; ln -sf libiptc.so.0.0.0 libiptc.so )
+( cd usr/lib ; rm -rf libip4tc.so.0 )
+( cd usr/lib ; ln -sf libip4tc.so.0.1.0 libip4tc.so.0 )
+( cd usr/lib ; rm -rf libiptc.so.0 )
+( cd usr/lib ; ln -sf libiptc.so.0.0.0 libiptc.so.0 )
 ( cd usr/lib ; rm -rf libip4tc.so )
-( cd usr/lib ; ln -sf libip4tc.so.0.0.0 libip4tc.so )
-( cd usr/lib ; rm -rf libip6tc.so.0 )
-( cd usr/lib ; ln -sf libip6tc.so.0.0.0 libip6tc.so.0 )
-( cd usr/lib ; rm -rf libxtables.so.5 )
-( cd usr/lib ; ln -sf libxtables.so.5.0.0 libxtables.so.5 )
+( cd usr/lib ; ln -sf libip4tc.so.0.1.0 libip4tc.so )
+( cd usr/bin ; rm -rf iptables-xml )
+( cd usr/bin ; ln -sf /usr/sbin/xtables-multi iptables-xml )
+( cd usr/sbin ; rm -rf ip6tables-save )
+( cd usr/sbin ; ln -sf xtables-multi ip6tables-save )
+( cd usr/sbin ; rm -rf iptables-restore )
+( cd usr/sbin ; ln -sf xtables-multi iptables-restore )
+( cd usr/sbin ; rm -rf iptables-save )
+( cd usr/sbin ; ln -sf xtables-multi iptables-save )
+( cd usr/sbin ; rm -rf iptables )
+( cd usr/sbin ; ln -sf xtables-multi iptables )
+( cd usr/sbin ; rm -rf ip6tables )
+( cd usr/sbin ; ln -sf xtables-multi ip6tables )
+( cd usr/sbin ; rm -rf ip6tables-restore )
+( cd usr/sbin ; ln -sf xtables-multi ip6tables-restore )
